<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit block
 *
 * @package    block_seenkit
 * @copyright  2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

class block_seenkit extends block_base {
    function init() {
        $this->title = get_string('block_title', 'block_seenkit');
    }

    function applicable_formats() {
        return array('all' => true);
    }

    function get_content () {
        global $USER, $CFG, $SESSION, $OUTPUT;
        require_once($CFG->libdir . '/authlib.php');

        $wwwroot = '';

        if ($this->content !== NULL) {
            return $this->content;
        }

        $wwwroot = $CFG->wwwroot;

        $this->content = new stdClass();
        $this->content->text = '';
		
		$systemcontext = context_system::instance();
		if(has_capability('block/seenkit:useseenkit', $systemcontext)){
			$this->content->text .= "\n".'<div><a href="'.$wwwroot.'/blocks/seenkit/index.php'.'">'.get_string('block_link','block_seenkit').'</a></div>';
		}

        return $this->content;
    }
	
	 /**
     * Allow the block to have a configuration page
     *
     * @return boolean
     */
    public function has_config() {
        return true;
    }
	
}
