<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * External API for block_seenkit.
 *
 * @package    block_seenkit
 * @copyright  2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace block_seenkit\external;
defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir . '/externallib.php');

use block_seenkit\seenkit\seenkit;


/**
 * External API for Seenkit.
 *
 * @package    local_seenkit
 * @copyright  2020 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class seenkit_external extends \external_api {

    /**
     * External function parameters.
     *
     * @return external_function_parameters
     */
    public static function check_processing_parameters() {
        return new \external_function_parameters([
            'recid' => new \external_value(PARAM_ALPHANUMEXT, 'The recording internal id')
        ]);
    }

    /**
     * Check recording processing status.
     *
     * @return array
     */
    public static function check_processing($recid) {
        global $CFG;

        $config = get_config('block_seenkit');
        $params = self::validate_parameters(self::check_processing_parameters(), ['recid' => $recid]);
        $context = \context_system::instance();
        self::validate_context($context);

        $seenkit = new seenkit($config->api_key, $config->api_secret,
        																							$config->api_url, $CFG->wwwroot);

        $check_result = json_decode($seenkit->get_unit_details($recid));
        $retval = array();
        $retval['processed'] = $check_result->processed;
        $retval['duration'] = $check_result->duration;
        $retval['slides'] = $check_result->slides;
        $retval['links'] = \html_writer::link(new \moodle_url('/blocks/seenkit/view.php?lid='.$check_result->internal_id), get_string('play', 'block_seenkit'))." | ".\html_writer::link(new \moodle_url('/blocks/seenkit/edit.php?lid='.$check_result->internal_id), get_string('edit'))." | ".\html_writer::link(new \moodle_url('/blocks/seenkit/index.php?action=delete&lid='.$check_result->internal_id), get_string('delete'), array("class"=>"snkt_del"));

        return $retval;
    }

    /**
     * External function return definition.
     *
     * @return external_single_structure
     */
    public static function check_processing_returns() {
      return new \external_single_structure([
          'processed' => new \external_value(PARAM_BOOL, 'View and edit links'),
          'links' => new \external_value(PARAM_RAW, 'View and edit links'),
          'duration' => new \external_value(PARAM_TEXT, 'Duration of the recording'),
          'slides' => new \external_value(PARAM_INT, 'The number of slides in the recording'),
      ]);
    }

}
