<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit block new lesson form
 *
 * @package     block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace block_seenkit\form;

require_once("$CFG->libdir/formslib.php");

class new_unit_form extends \moodleform {

	private static $maxbytes = 20000;
	private $returnurl;
	private $cmid;
	private $qid;
	private $idnumber;

	public function __construct($returnurl = null, $cmid = null, $qid = null, $idnumber = null){

		$this->returnurl = $returnurl;
		$this->cmid = $cmid;
		$this->qid = $qid;
		$this->idnumber = $idnumber;

		parent::__construct();
	}

    //Add elements to form
    public function definition() {
        global $CFG;

        $mform = $this->_form;

        $mform->addElement('text', 'title', get_string('title','block_seenkit'), array('size' => 40));
		if($this->idnumber != null){
			$mform->setDefault('title', get_string('comment_for_question', 'block_seenkit').' '.$this->idnumber);
		}
		$mform->setType('title', PARAM_NOTAGS);
		$mform->addRule('title', get_string('error_required', 'block_seenkit'), 'required', '', 'client', false, false);
		$mform->addRule('title', get_string('error_title_length', 'block_seenkit'), 'maxlength', 64, 'client', false, false);
		$mform->addRule('title', get_string('error_title_length', 'block_seenkit'), 'minlength', 4, 'client', false, false);


		$mform->addElement('text', 'description', get_string('description'), array('size' => 50));
		$mform->setType('description', PARAM_NOTAGS);
		$mform->addRule('description', get_string('error_desc_too_long', 'block_seenkit'), 'maxlength', 150, 'client', false, false);

		$mform->addElement('filepicker', 'userfile', get_string('presentation_file', 'block_seenkit'), null, array('maxbytes' => $this->maxbytes, 'accepted_types' => array('.ppt','.pptx','.jpg','.png','.pdf','.gif')));
		$mform->addHelpButton('userfile', 'presentation_file', 'block_seenkit');

		$mform->addElement('hidden', 'returnurl', $this->returnurl);
		$mform->addElement('hidden', 'cmid', $this->cmid);
		$mform->addElement('hidden', 'qid', $this->qid);

		$this->add_action_buttons(true, get_string('new_unit','block_seenkit'));

    }

    //Custom validation should be added here
    function validation($data, $files) {

        return array();
    }
}
