<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace block_seenkit\output;

use renderable;

/**
 * Component representing a list of units.
 *
 * @copyright 2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @package mod_scorm
 */
class lesson_list implements renderable {


    /**
     * @var object lesson list
     */
    public $units;

    /**
     * Constructor.
     *
     * @param object $lessons
     * @param int $user_id
     */
    public function __construct($units, $platform_units, $site_admin) {
  		if(!$site_admin){
  			$this->units = $this->filter_lessons($units, $platform_units);
  		}else{
  			$this->units = $this->sortAdminLessons($units, $platform_units);
  		}
    }

	 /**
     * Filter the lesson list keeping only this user's lessons.
     *
     * @param object $lessons
     * @param int $user_id
     */

	private function filter_lessons($units, $platform_units){

		foreach($units as $key=>$unit){
			if(!in_array($unit->internal_id, $platform_units)){
				unset($units[$key]);
			}
		}
		return $units;
	}

  /**
    * Order lessons by teacher.
    *
    * @param object $lessons
    */
	private function sortAdminLessons($units, $platform_units){

		$units_full = array();
		foreach($units as $unit){
		  if(array_key_exists($unit->internal_id, $platform_units)){
				$unit->teacher_firstname = $platform_units[$unit->internal_id]->firstname;
				$unit->teacher_lastname = $platform_units[$unit->internal_id]->lastname;
				$units_full[] = $unit;
		  }
		}

		usort($units_full, function($a, $b){
			return strcmp($a->teacher_lastname, $b->teacher_lastname);
		});
		return $units_full;
	}

}
