<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * The Seenkit API client class
 *
 * @package   local_seenkit
 * @copyright 2020 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace block_seenkit\seenkit;

/*
require_once($CFG->dirroot . '/blocks/seenkit/vendor/autoload.php');

use Jose\Component\Core\JWK;
use Jose\Easy\Build;
use Jose\Component\KeyManagement\JWKFactory;
*/

use block_seenkit\jwt\JWT;

class seenkit{

	private static $logout_page = "/blocks/seenkit/index.php";
	private static $uploads_dir = "/blocks/seenkit/uploads/";

	private $api_key;
	private $api_secret;
	private $api_url;
	private $logout_url;
	private $uploads_url;
	private $allow_url;
	private $scorm_download_url;

	function __construct($api_key, $api_secret, $api_url, $server_url, $logout_page = null){
		global $CFG;

		$this->api_key = $api_key;
		$this->api_secret =  $api_secret;
		$this->api_url =  $api_url.'api/';
		$this->scorm_download_url = $api_url.'scormpackages/';

		if($logout_page != null){
			$this->logout_url = $server_url.$logout_page;
		}else{
			$this->logout_url = $server_url.self::$logout_page;
		}

		$this->uploads_url = $server_url.self::$uploads_dir;
		$this->allow_url = $this->get_allow_url($server_url);
	}

	public function getScormDownloadUrl(){
		return $this->scorm_download_url;
	}

	public function update_unit_details($unitId, $title = null, $description = null,
						$show_cursor = null, $show_video = null, $show_speaker_name = null,
						$speaker_name = null, $show_date = null, $extra_info = null){

		$api_method = "units/".$unitId;
		$http_method = "put";
		$put_data = array();

		if(null !== $title){
			$put_data['title'] = $title;
		}

		if(null !== $description){
			$put_data['description'] = $description;
		}

		if(null !== $show_cursor){
			$put_data['show_cursor'] = $show_cursor;
		}

		if(null !== $show_video){
			$put_data['show_video'] = $show_video;
		}

		if(null !== $show_speaker_name){
			$put_data['show_speaker_name'] = $show_speaker_name;
		}

		if(null !== $speaker_name){
			$put_data['speaker_name'] = $speaker_name;
		}

		if(null !== $show_date){
			$put_data['show_date'] = $show_date;
		}

		if(null !== $extra_info){
			$put_data['extra_info'] = $extra_info;
		}

		$return_json = $this->call($api_method, $http_method, $put_data);
		return $return_json;
	}

	public function get_unit_link($unitId){
		$api_method = "units/".$unitId."/link";
		$http_method = "get";
		$return_json = $this->call($api_method, $http_method);
		return $return_json;
	}

	public function get_unit_scorm($unitId, $orgName, $itemTitle, $eb){
		$api_method = "units/".$unitId."/scorm/".urlencode($orgName)."/".urlencode($itemTitle)."/".$eb;
		$http_method = "get";
		$return_json = $this->call($api_method, $http_method);
		return $return_json;
	}

	public function get_unit_details($unitId){
		$api_method = "units/".$unitId;
		$http_method = "get";
		$return_json = $this->call($api_method, $http_method);
		return $return_json;
	}

	public function list_units(){
		$api_method = "units";
		$http_method = "get";
		$return_json = $this->call($api_method, $http_method);
		return $return_json;
	}

	public function create_unit($pres_file, $title, $description, $type, $display_name, $extra_info){
		$api_method = "units";
		$http_method = "post";

		if(substr($pres_file, 0, 5) != 'http:' && substr($pres_file, 0, 6) != 'https:'){
			$pres_file = $this->uploads_url.$pres_file;
		}

		$post_data = array('pres_file'=>$pres_file, 'title'=>$title, 'description'=>$description, 'logout_url'=>$this->logout_url, 'allow_url'=>$this->allow_url, 'extra_info'=>$extra_info);
		$return_json = $this->call($api_method, $http_method, $post_data);
		return $return_json;
	}

	public function get_edit_unit_token($unitId){
		$api_method = "editToken/".$unitId;
		$http_method = "post";
		$post_data = http_build_query(array('logout_url'=>$this->logout_url));
		$return_json = $this->call($api_method, $http_method, $post_data);
		return $return_json;
	}

	public function delete_unit($unitId){
		$api_method = "units/".$unitId;
		$http_method = "delete";
		$return_json = $this->call($api_method, $http_method);
		return $return_json;
	}

	private function call($api_method, $http_method, $data = null){
		$jwt_token = $this->get_token();
		$url = $this->api_url.$api_method;
		return($this->call_url($url, $http_method, $data, $jwt_token));
	}

	private function call_url($url, $http_method, $data, $token){
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		$headers = array();
		$headers[] = "Authorization: bearer ".$token;
		if($http_method == "post"){
			curl_setopt($ch, CURLOPT_POST, TRUE);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
		}else if($http_method == "delete"){
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
		}else if($http_method == "put"){
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
			$headers[] = "Content-Type: application/x-www-form-urlencoded";
			curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data, '', '&'));
		}
		curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
		if(!$result = curl_exec($ch)){
			throw new \moodle_exception('Connection error: php cURL could not connect to the Seenkit API', 'block_seenkit');
		}

		$httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if($httpcode != 200){
			throw new \moodle_exception(get_string('apierror','block_seenkit', json_decode($result)->error), 'block_seenkit');
		}
		
		return $result;
	}

	private function get_token(){
		$jwt = JWT::encode(
			['exp'=>time()+3600, 'iss'=>$this->api_key],
			$this->api_secret,
			'HS256',
		);
		
		return $jwt;
	}

	private function build_url($api_method){
		$url = $this->api_url.$api_method."/".$this->api_key;
		$url .= "/".(sha1($url.$this->api_secret));
		return $url;
	}

	private function get_allow_url($moodle_url){
		$allow_url = (substr($moodle_url, 0, 5) == "https")?substr($moodle_url, 8):substr($moodle_url, 7);
		$slash_pos = strpos($allow_url, "/");
		if($slash_pos !== false){
			$allow_url = substr($allow_url, 0, $slash_pos);
		}
		return $allow_url;
	}
}

?>
