<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * A scheduled task for deleteting files used as presentions during the recording.
 *
 * @package 	block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace block_seenkit\task;

defined('MOODLE_INTERNAL') || die();

/**
 * A scheduled task for deleteting files used as presentions during the recording.
 *
 * @package 	block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class delete_presentation_files_task extends \core\task\scheduled_task {

    private static $expiretime = 900;

    /**
     * Get a descriptive name for this task (shown to admins).
     *
     * @return string
     */
    public function get_name() {
        return get_string('taskdeletepresentationfiles', 'block_seenkit');
    }

    /**
     * Execute.
     */
    public function execute() {
        global $DB, $CFG;

        $now = time();
        $uploads_dir = $CFG->dirroot.'/blocks/seenkit/uploads';
        if ($handle = opendir($uploads_dir)){
          while (false !== ($entry = readdir($handle))) {
            if ($entry != "." && $entry != ".." && $entry != "empty_pres.pptx") {
              $ctime = filectime($uploads_dir."/".$entry);
              if($ctime < ($now - self::$expiretime) && is_dir($uploads_dir."/".$entry)) {
                $this->empty_directory($uploads_dir."/".$entry);
                rmdir($uploads_dir."/".$entry);
              }
            }
          }
        }
      }


      /**
      * Private function for deleting files in a directory
      * @param $folder_name the local path of the folder.
      */
      private function empty_directory($folder_name){
        if ($handle = opendir($folder_name)){
          while (false !== ($entry = readdir($handle))) {
            if ($entry != "." && $entry != ".." && !is_dir($folder_name."/".$entry)) {
              unlink($folder_name."/".$entry);
            }
          }
        }
      }
}
