<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Web service block template external functions and service definitions.
 *
 * @package   block_seenkit
 * @copyright 2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

// We defined the web service functions to install.
$functions = [
    'block_seenkit_check_processing' => [
        'classname'     => 'block_seenkit\external\seenkit_external',
        'methodname'    => 'check_processing',
        'description'   => 'Get the processing status of a Seenkit recording.',
        'type'          => 'read',
        'capabilities'  => 'block/seenkit:useseenkit',
        'ajax'          => true
    ],
];

$services = array(
      'seenkitservice' => array(                                                // the name of the web service
          'functions' => array ('block_seenkit_check_processing'), // web service functions of this service
          'requiredcapability' => 'block/seenkit:useseenkit',                // if set, the web service user need this capability to access
                                                                              // any function of this service. For example: 'some/capability:specified'
          'restrictedusers' => 0,                                             // if enabled, the Moodle administrator must link some user to this service
                                                                              // into the administration
          'enabled' => 1,                                                       // if enabled, the service can be reachable on a default installation
          'shortname' =>  '',       // optional – but needed if restrictedusers is set so as to allow logins.
          'downloadfiles' => 0,    // allow file downloads.
          'uploadfiles'  => 0      // allow file uploads.
       )
  );
