<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit block plugin edit lesson page
 *
 * @package     block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');

$PAGE->set_pagelayout('standard');

// Check permissions
require_login();
require_capability('block/seenkit:useseenkit',context_system::instance());

$PAGE->set_url('/blocks/seenkit/edit.php');
$PAGE->set_title(get_string('seenkit_units_flatnav', 'block_seenkit'));
$PAGE->set_heading(get_string('seenkit_units_flatnav', 'block_seenkit'));

$PAGE->navbar->add(get_string('seenkit_units_flatnav', 'block_seenkit'), new moodle_url('/blocks/seenkit/index.php'));
$PAGE->navbar->add(get_string('edit_unit', 'block_seenkit'));

$output = $PAGE->get_renderer('block_seenkit');
echo $output->header();

$lid = (isset($_GET['lid']) && $_GET['lid'] != '')?$_GET['lid']:null;

// Setup the form
$mform = new \block_seenkit\form\edit_unit_form();

if($mform->is_cancelled()){

	redirect(new moodle_url('/blocks/seenkit/index.php'), '', 10);

}else if($form_data = $mform->get_data()){

	// Set up the seenkit connection to save new values
	$config = get_config('block_seenkit');
	$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);

	$show_cursor = (isset($form_data->show_cursor))?'Y':'N';

	$show_video = (isset($form_data->show_video))?'Y':'N';

	$show_speaker_name = (isset($form_data->show_speaker_name))?'Y':'N';

	$speaker_name = $form_data->speaker_name;

	$show_date = (isset($form_data->show_date))?'Y':'N';


	$update_result = json_decode($seenkit->update_unit_details($form_data->lid, $form_data->title, $form_data->description, $show_cursor, $show_video, $show_speaker_name, $speaker_name, $show_date));

	if($update_result->res != 'ok'){
		redirect(new moodle_url('/blocks/seenkit/index.php'), get_string('unit_update_error', 'block_seenkit'), null, \core\output\notification::NOTIFY_ERROR);
	}else{
		redirect(new moodle_url('/blocks/seenkit/index.php'), get_string('unit_update_success', 'block_seenkit'), null, \core\output\notification::NOTIFY_SUCCESS);
	}

}else{

	// Set up the seenkit connection to get current values
	$config = get_config('block_seenkit');
	$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);
	$lesson_details = json_decode($seenkit->get_unit_details($lid));

	$toform = new stdClass();
	$toform->lid = $lid;
	$toform->title = $lesson_details->title;
	$toform->description = $lesson_details->description;
	$toform->speaker_name = $lesson_details->lesson_props->speaker_name;
	$toform->has_video = ($lesson_details->type == "V")?"1":"0";

	if($lesson_details->lesson_props->show_cursor == 'Y'){
		$toform->show_cursor = 1;
	}

	if($lesson_details->lesson_props->show_speaker_name == 'Y'){
		$toform->show_speaker_name = 1;
	}

	if($lesson_details->lesson_props->show_video == 'Y'){
		$toform->show_video = 1;
	}

	if($lesson_details->lesson_props->show_date == 'Y'){
		$toform->show_date = 1;
	}

	// Set current values to form
	$mform->set_data($toform);

	$mform->display();
}

echo $output->footer();
