<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit local plugin main page
 *
 * @package     local_seenkit
 * @copyright  	2020 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');

$lid 	= optional_param('lid', 0, PARAM_ALPHANUMEXT);
$action	= optional_param('action', null, PARAM_ALPHANUMEXT);
$new_recording_int_id 	= optional_param('intid', 0, PARAM_ALPHANUMEXT);
$PAGE->set_pagelayout('standard');

// Check permissions
require_login();
require_capability('block/seenkit:useseenkit',context_system::instance());

// New recording to be saved in DB
if($new_recording_int_id){
	$check_sql = 'select * from {block_seenkit} WHERE '. $DB->sql_compare_text('seenkit_internal_id') . ' = ' .$DB->sql_compare_text(':seenkit_internal_id');
	$params = array('seenkit_internal_id' => $new_recording_int_id);
	$check = $DB->get_records_sql($check_sql, $params);
	if(!count($check)) { // Check to avoid double insert when page is reloaded
		$new_recording_data = new \stdClass();
		$new_recording_data->userid = $USER->id;
		$new_recording_data->timecreated = time();
		$new_recording_data->seenkit_internal_id = $new_recording_int_id;
		$DB->insert_record('block_seenkit', $new_recording_data);
	}
}

// Set up Seenkit connection
$config = get_config('block_seenkit');
$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);

// If we have to delete a lesson, let's delete it
if($action != null && $action == 'delete' && $lid){
	// If the lesson is used in a course seenkit-activity we can't delete it
	$mod_plugins = core_plugin_manager::instance()->get_plugins_of_type('mod');
	if(array_key_exists('seenkit', $mod_plugins)){
		$check_sql = 'select * from {seenkit} WHERE '. $DB->sql_compare_text('seenkit_internal_id') . ' = ' .$DB->sql_compare_text(':seenkit_internal_id');
		$params = array('seenkit_internal_id' => $lid);
		$check = $DB->get_records_sql($check_sql, $params);
		if(count($check) > 0){
			\core\notification::warning(get_string('cannot_delete_used_unit', 'local_seenkit'));
			$can_delete = false;
		}else{
			$can_delete = true;
		}
	}else{
		$can_delete = true;
	}

	if($can_delete){
		$del_result = json_decode($seenkit->delete_unit($lid));
		if($del_result->res != "ok"){
			\core\notification::warning(get_string('cannot_delete_unit', 'block_seenkit'));
		}else{
			$DB->delete_records_select('block_seenkit', $DB->sql_compare_text('seenkit_internal_id') . ' = ' .$DB->sql_compare_text(':seenkit_internal_id'),  array('seenkit_internal_id' => $lid));
		}
	}
}

$PAGE->set_url('/blocks/seenkit/index.php');
$PAGE->set_title(get_string('seenkit_units_flatnav', 'block_seenkit'));
$PAGE->set_heading(get_string('seenkit_units_flatnav', 'block_seenkit'));

// Import JS for modal confirm
$PAGE->requires->js_call_amd('block_seenkit/modals', 'init', array(get_string('delete_confirm_title','block_seenkit'), get_string('delete_confirm_text','block_seenkit'), '.snkt_del'));
$PAGE->requires->js_call_amd('block_seenkit/check_processing', 'checking');

$output = $PAGE->get_renderer('block_seenkit');
echo $output->header();


// Get all units from Seenkit
$units = json_decode($seenkit->list_units());

// Get the units of the user on this Moodle platform
if(!is_siteadmin()){
	$platform_units = $DB->get_fieldset_select('block_seenkit', 'seenkit_internal_id', 'userid = :userid', array('userid' => $USER->id));
}else{
	$sql = "SELECT seenkit_internal_id, firstname, lastname
					FROM {block_seenkit} ls
					JOIN {user} u ON u.id = ls.userid";
	$full_units = $DB->get_records_sql($sql, $params);
	$platform_units = array();
	foreach ($full_units as $key => $full_unit) {
		$platform_units[$full_unit->seenkit_internal_id] = $full_unit;
	}
}

// Render the lesson list
$lesson_list = new \block_seenkit\output\lesson_list($units, $platform_units, is_siteadmin());
$output = $PAGE->get_renderer('block_seenkit');
echo $output->render($lesson_list);
echo html_writer::start_tag('form', array('method'=>'POST','action'=>new moodle_url('/blocks/seenkit/new.php')));
echo html_writer::tag('input', '', array('type'=>'submit', 'class'=>'btn btn-primary', 'value'=>get_string('new_unit', 'block_seenkit')));
echo html_writer::end_tag('form');

echo $output->footer();
