<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit configuration form
 *
 * @package 	mod_seenkit
 * @copyright  	2020 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


defined('MOODLE_INTERNAL') || die;

require_once($CFG->dirroot.'/course/moodleform_mod.php');

class mod_seenkit_mod_form extends moodleform_mod {

	function definition() {

    global $CFG, $DB, $USER;

    $mform = $this->_form;

    $config = get_config('block_seenkit');
	$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);
	$lessons = json_decode($seenkit->list_units());

    //-------------------------------------------------------
    $mform->addElement('header', 'general', get_string('general', 'form'));
    $mform->addElement('text', 'name', get_string('name'), array('size'=>'48'));
    if (!empty($CFG->formatstringstriptags)) {
        $mform->setType('name', PARAM_TEXT);
    } else {
        $mform->setType('name', PARAM_CLEANHTML);
    }
    $mform->addRule('name', null, 'required', null, 'client');
    $mform->addRule('name', get_string('maximumchars', '', 255), 'maxlength', 255, 'client');
    $this->standard_intro_elements();

    //-------------------------------------------------------
    $mform->addElement('header', 'contentsection', get_string('lessonheader', 'seenkit'));

	$lessons_radio_array = array();
	if(is_siteadmin()){
		$platform_units = $DB->get_fieldset_sql('select seenkit_internal_id from {block_seenkit}');
	}else{
		$platform_units = $DB->get_fieldset_select('block_seenkit', 'seenkit_internal_id', 'userid = :userid', array('userid' => $USER->id));
	}
	foreach($lessons as $lesson){
		if(in_array($lesson->internal_id, $platform_units)){
			$lessons_radio_array[] = $mform->createElement('radio', 'seenkit_internal_id', '',$lesson->title, $lesson->internal_id, 'class="seenkit-radio"');
		}
	}

	$mform->addGroup($lessons_radio_array, 'lessonsradioar', get_string('lessonheader', 'seenkit'), array(' '), false);
	$mform->addRule('lessonsradioar', null, 'required', null, 'client');


    //-------------------------------------------------------
    $this->standard_coursemodule_elements();

    //-------------------------------------------------------
    $this->add_action_buttons();

    //-------------------------------------------------------
    $mform->addElement('hidden', 'revision');
    $mform->setType('revision', PARAM_INT);
    $mform->setDefault('revision', 1);
  }
}
