<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit block plugin new lesson page
 *
 * @package     block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');
require_once("$CFG->libdir/filestorage/file_exceptions.php");
require('locallib.php');

$PAGE->set_pagelayout('standard');

// Check permissions
// UE Check ss
require_login();
require_capability('block/seenkit:useseenkit',context_system::instance());

$PAGE->set_url('/blocks/seenkit/new.php');
$PAGE->set_title(get_string('seenkit_units_flatnav', 'block_seenkit'));
$PAGE->set_heading(get_string('seenkit_units_flatnav', 'block_seenkit'));

$PAGE->navbar->add(get_string('seenkit_units_flatnav', 'block_seenkit'), new moodle_url('/blocks/seenkit/index.php'));
$PAGE->navbar->add(get_string('new_unit', 'block_seenkit'));

$output = $PAGE->get_renderer('block_seenkit');
echo $output->header();

// Setup form
$mform = new \block_seenkit\form\new_unit_form();

if($mform->is_cancelled()){

	redirect(new moodle_url('/blocks/seenkit/index.php'), '', 10);

}else if($form_data = $mform->get_data()){

	if($mform->get_new_filename('userfile')){

		$new_dir_name = create_uploads_folder();
		$new_file_path = $new_dir_name.'/'.str_replace(" ", "_", $mform->get_new_filename('userfile'));

		$fullpath = $CFG->dirroot.'/blocks/seenkit/uploads/'.$new_file_path;
		$override = true;
		if(!$success = $mform->save_file('userfile', $fullpath, $override)){
			throw new file_exception('Could not upload the file');
		}
	}else{
		$new_file_path = 'empty_pres.pptx';
	}

	$config = get_config('block_seenkit');
	$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);

	$extra_info = array("ext_platform"=>$CFG->wwwroot);

	$create_resp = json_decode($seenkit->create_unit($new_file_path, $form_data->title, $form_data->description, '', $USER->firstname." ".$USER->lastname, json_encode($extra_info)));

	$token1 = $create_resp->apiToken1;
	$token2 = sha1($token1.$config->api_key.$config->api_secret);

	$recordUrl = 'https://api.seenkit.com/api/record_api?t1='.$token1.'&t2='.$token2;

	redirect($recordUrl);

}else{

	$config = get_config('block_seenkit');
	$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);
	$units = json_decode($seenkit->list_units());
	$platform_units = $DB->get_fieldset_select('block_seenkit', 'seenkit_internal_id', 'userid = :userid', array('userid' => $USER->id));
	$user_units = new \block_seenkit\output\lesson_list($units, $platform_units, is_siteadmin());
	$check = true;
	foreach($user_units->units as $user_unit){
		if(!$user_unit->processed){
			\core\notification::warning(get_string('before_recording', 'block_seenkit'));
			$check = false;
			break;
		}
	}

	if($check){
		$mform->display();
	}else{
		echo html_writer::link(new moodle_url('/blocks/seenkit/index.php'), get_string('back'));
	}
}



echo $output->footer();
