<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Defines the renderer for block_seenkit.
 *
 * @package   block_seenkit
 * @copyright 2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/**
 * The renderer for block_seenkit.
 *
 * @copyright 2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class block_seenkit_renderer extends plugin_renderer_base {

	protected function render_lesson_list (\block_seenkit\output\lesson_list $lesson_list){
		global $DB;

		$strname        = get_string('title', 'block_seenkit');
		$strintro       = (is_siteadmin())?get_string('user'):get_string('description');
		$strcreated 	= get_string('created', 'block_seenkit');
		$strplay 		= get_string('play');
		$strduration	= get_string('duration', 'block_seenkit');
		$strslides		= get_string('slides', 'block_seenkit');

		// Build the table
		$table = new html_table();
		$table->attributes['class'] = 'generaltable mod_index';
		$table->head  = array ($strname, $strintro, $strcreated, $strduration, $strslides, ' ');
		$table->align = array ('left', 'left', 'left', 'center', 'center', 'center');
		$table->wrap = array(null, null, 'nowrap', 'nowrap', 'nowrap', 'nowrap');
		$table->colclasses = array('title_td table_row', 'table_row', 'table_row', 'table_row', 'table_row', 'table_row');

		$k = 0;
		foreach($lesson_list->units as $unit){

			$k++;
			if($unit->processed == 1){
				$table->data[] = array(
					$unit->title,
					(is_siteadmin())?$unit->teacher_firstname." ".$unit->teacher_lastname:$unit->description,
					substr($unit->date, 0, 10),
					$unit->duration,
					$unit->slides,
					html_writer::link(new moodle_url('/blocks/seenkit/view.php?lid='.$unit->internal_id), get_string('play', 'block_seenkit'))." | ".html_writer::link(new moodle_url('/blocks/seenkit/edit.php?lid='.$unit->internal_id), get_string('edit'))." | ".html_writer::link(new moodle_url('/blocks/seenkit/index.php?action=delete&lid='.$unit->internal_id), get_string('delete'), array("class"=>"snkt_del"))
				);
			}else{
				$table->data[] = array(
					$unit->title,
					(is_siteadmin())?$unit->teacher_firstname." ".$unit->teacher_lastname:$unit->description,
					substr($unit->date, 0, 10),
					html_writer::start_span('', array('id'=>'dur-'.$unit->internal_id)).''.html_writer::end_span(),
					html_writer::start_span('', array('id'=>'slides-'.$unit->internal_id)).''.html_writer::end_span(),
					html_writer::tag('img','',array('src'=>new moodle_url('/blocks/seenkit/pix/ajax-loader.gif'), 'class'=>'loader_img')).'&nbsp;'.html_writer::start_span('processing', array('id'=>$unit->internal_id,'class'=>'processing_span')).get_string('processing', 'block_seenkit').html_writer::end_span()
				);
			}
		}

		return html_writer::table($table);
	}

}
