<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit module version information
 *
 * @package    mod_seenkit
 * @copyright  2020 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');
require_once($CFG->dirroot.'/mod/seenkit/lib.php');
require_once($CFG->libdir.'/completionlib.php');

$id      = optional_param('id', 0, PARAM_INT); // Course Module ID

if (!$cm = get_coursemodule_from_id('seenkit', $id)) {
	print_error('invalidcoursemodule');
}
$seenkit_lesson = $DB->get_record('seenkit', array('id'=>$cm->instance), '*', MUST_EXIST);

$course = $DB->get_record('course', array('id'=>$cm->course), '*', MUST_EXIST);

require_course_login($course, true, $cm);
$context = context_module::instance($cm->id);

// Completion and trigger events.
seenkit_view($seenkit_lesson, $course, $cm, $context);
$PAGE->set_pagelayout('standard');
$PAGE->set_url('/mod/seenkit/view.php', array('id' => $cm->id));

$config = get_config('block_seenkit');
$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key, $config->api_secret, $config->api_url, $CFG->wwwroot);
$lesson_details = json_decode($seenkit->get_unit_details($seenkit_lesson->seenkit_internal_id));

$PAGE->set_activity_record($seenkit_lesson);

echo $OUTPUT->header();

if (isset($options['printheading']) || !empty($options['printheading'])) {
    echo $OUTPUT->heading(format_string($seenkit_lesson->name), 2);
}

if (!empty($options['printintro'])) {
    if (trim(strip_tags($page->intro))) {
        echo $OUTPUT->box_start('mod_introbox', 'pageintro');
        echo format_module_intro('seenkit', $seenkit_lesson, $cm->id);
        echo $OUTPUT->box_end();
    }
}

echo html_writer::start_tag('iframe', array("src"=>$lesson_details->embed_link,
                                    "style"=>"width: 100%; height: 550px;",
                                    "frameborder"=>"0"));
echo html_writer::end_tag('iframe');


echo $OUTPUT->footer();
