<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Seenkit block plugin main page
 *
 * @package     block_seenkit
 * @copyright  	2022 onwards Abaco Technology  {@link https://www.abacotechnology.com}
 * @license    	http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');
$recording_id = optional_param('lid', '', PARAM_ALPHANUMEXT);
$PAGE->set_pagelayout('standard');

// Check permissions
require_login();
require_capability('block/seenkit:useseenkit',context_system::instance());

$PAGE->set_url('/blocks/seenkit/view.php');
$PAGE->set_title(get_string('seenkit_units_flatnav', 'block_seenkit'));
$PAGE->set_heading(get_string('seenkit_units_flatnav', 'block_seenkit'));

$PAGE->navbar->add(get_string('seenkit_units_flatnav', 'block_seenkit'),
                    new moodle_url('/blocks/seenkit/index.php'));
$PAGE->navbar->add(get_string('play_unit', 'block_seenkit'));

$output = $PAGE->get_renderer('block_seenkit');
echo $output->header();

// Get the lesson link
$config = get_config('block_seenkit');
$seenkit = new \block_seenkit\seenkit\seenkit($config->api_key,
          $config->api_secret, $config->api_url, $CFG->wwwroot);
$lesson_details = json_decode($seenkit->get_unit_details($recording_id));

// Show the lesson
echo html_writer::start_tag('iframe', array("src"=>$lesson_details->embed_link,
                                    "style"=>"width: 100%; height: 550px;",
                                    "frameborder"=>"0"));
echo html_writer::end_tag('iframe');
echo html_writer::link(new moodle_url('/block/seenkit/index.php'), get_string('back'));

echo $output->footer();
